@@ -4,6 +4,8 @@ use strict;
 use warnings;
 
 sub isEnabled {
+    my (%params) = @_;
+    return 0 if $params{no_category}->{virtualmachine};
     return 1;
 }
 
